==> surveyplat-proof-common-zjgg-1.0.0-20191014.054435-13-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzXmxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2019/9/10
 * @description 增减挂钩项目信息表
 */
@Table(name = "dcjz_xmxx")
public class DcjzXmxx {
    //项目ID
    @Id
    private String xmid;
    //项目编号
    private String xmbh;
    //项目名称
    private String xmmc;
    //行政区代码
    private String xzqdm;
    //行政区名称
    private String xzqmc;
    //验收编号
    private String ysbh;
    //地块个数
    private Integer dkgs;
    //应举证地块个数
    private Integer yjzdkgs;
    //验收文号
    private String yswh;
    //验收时间
    private Date yssj;
    //项目建设规模
    private Float xmjsgm;
    //新增耕地面积
    private Float xzgdmj;
    //项目总资金
    private Float xmzzj;
    //项目范围
    private String xmqfw;
    //县级核查人
    private String xjhcr;
    //县级核查状态
    private String xjhczt;
    //县级核查时间
    private Date xjhcsj;
    //县级核查意见
    private String xjhcyj;
    //省级核查状态
    private String sjhczt;
    //省级核查人
    private String sjhcr;
    //省级核查时间
    private Date sjhcsj;
    //省级核查意见
    private String sjhcyj;
    //项目举证状态
    private String xmjzzt;
    //是否重新举证
    private String sfcxjz;
    //备注
    private String bz;
    //是否签订管护协议
    private String sfqdghxy;

    //县级项目结论
    private String xjxmjl;
    //省级项目结论
    private String sjxmjl;
    //省级备注
    private String sjbz;

    public String getXjxmjl() {
        return xjxmjl;
    }

    public void setXjxmjl(String xjxmjl) {
        this.xjxmjl = xjxmjl;
    }

    public String getSjxmjl() {
        return sjxmjl;
    }

    public void setSjxmjl(String sjxmjl) {
        this.sjxmjl = sjxmjl;
    }

    public String getSjbz() {
        return sjbz;
    }

    public void setSjbz(String sjbz) {
        this.sjbz = sjbz;
    }

    public String getSfqdghxy() {
        return sfqdghxy;
    }

    public void setSfqdghxy(String sfqdghxy) {
        this.sfqdghxy = sfqdghxy;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXmbh() {
        return xmbh;
    }

    public void setXmbh(String xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getYsbh() {
        return ysbh;
    }

    public void setYsbh(String ysbh) {
        this.ysbh = ysbh;
    }

    public Integer getDkgs() {
        return dkgs;
    }

    public void setDkgs(Integer dkgs) {
        this.dkgs = dkgs;
    }

    public Integer getYjzdkgs() {
        return yjzdkgs;
    }

    public void setYjzdkgs(Integer yjzdkgs) {
        this.yjzdkgs = yjzdkgs;
    }

    public String getYswh() {
        return yswh;
    }

    public void setYswh(String yswh) {
        this.yswh = yswh;
    }

    public Date getYssj() {
        return yssj;
    }

    public void setYssj(Date yssj) {
        this.yssj = yssj;
    }

    public Float getXmjsgm() {
        return xmjsgm;
    }

    public void setXmjsgm(Float xmjsgm) {
        this.xmjsgm = xmjsgm;
    }

    public Float getXzgdmj() {
        return xzgdmj;
    }

    public void setXzgdmj(Float xzgdmj) {
        this.xzgdmj = xzgdmj;
    }

    public Float getXmzzj() {
        return xmzzj;
    }

    public void setXmzzj(Float xmzzj) {
        this.xmzzj = xmzzj;
    }

    public String getXmqfw() {
        return xmqfw;
    }

    public void setXmqfw(String xmqfw) {
        this.xmqfw = xmqfw;
    }

    public String getXjhcr() {
        return xjhcr;
    }

    public void setXjhcr(String xjhcr) {
        this.xjhcr = xjhcr;
    }

    public String getXjhczt() {
        return xjhczt;
    }

    public void setXjhczt(String xjhczt) {
        this.xjhczt = xjhczt;
    }

    public Date getXjhcsj() {
        return xjhcsj;
    }

    public void setXjhcsj(Date xjhcsj) {
        this.xjhcsj = xjhcsj;
    }

    public String getXjhcyj() {
        return xjhcyj;
    }

    public void setXjhcyj(String xjhcyj) {
        this.xjhcyj = xjhcyj;
    }

    public String getSjhczt() {
        return sjhczt;
    }

    public void setSjhczt(String sjhczt) {
        this.sjhczt = sjhczt;
    }

    public String getSjhcr() {
        return sjhcr;
    }

    public void setSjhcr(String sjhcr) {
        this.sjhcr = sjhcr;
    }

    public Date getSjhcsj() {
        return sjhcsj;
    }

    public void setSjhcsj(Date sjhcsj) {
        this.sjhcsj = sjhcsj;
    }

    public String getSjhcyj() {
        return sjhcyj;
    }

    public void setSjhcyj(String sjhcyj) {
        this.sjhcyj = sjhcyj;
    }

    public String getXmjzzt() {
        return xmjzzt;
    }

    public void setXmjzzt(String xmjzzt) {
        this.xmjzzt = xmjzzt;
    }

    public String getSfcxjz() {
        return sfcxjz;
    }

    public void setSfcxjz(String sfcxjz) {
        this.sfcxjz = sfcxjz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> surveyplat-proof-common-zjgg-1.0.0-20191022.095956-20-sources.jar: cn/gtmap/surveyplat/common/entity/DcjzXmxx.java <==
package cn.gtmap.surveyplat.common.entity;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2019/9/10
 * @description 增减挂钩项目信息表
 */
@Table(name = "dcjz_xmxx")
public class DcjzXmxx {
    //项目ID
    @Id
    private String xmid;
    //项目编号
    private String xmbh;
    //项目名称
    private String xmmc;
    //行政区代码
    private String xzqdm;
    //行政区名称
    private String xzqmc;
    //验收编号
    private String ysbh;
    //地块个数
    private Integer dkgs;
    //应举证地块个数
    private Integer yjzdkgs;
    //验收文号
    private String yswh;
    //验收时间
    private Date yssj;
    //项目建设规模
    private Float xmjsgm;
    //新增耕地面积
    private Float xzgdmj;
    //项目总资金
    private Float xmzzj;
    //项目范围
    private String xmqfw;
    //县级核查人
    private String xjhcr;
    //县级核查状态
    private String xjhczt;
    //县级核查时间
    private Date xjhcsj;
    //县级核查意见
    private String xjhcyj;
    //省级核查状态
    private String sjhczt;
    //省级核查人
    private String sjhcr;
    //省级核查时间
    private Date sjhcsj;
    //省级核查意见
    private String sjhcyj;
    //项目举证状态
    private String xmjzzt;
    //是否重新举证
    private String sfcxjz;
    //备注
    private String bz;
    //是否签订管护协议
    private String sfqdghxy;

    //县级项目结论
    private String xjxmjl;
    //省级项目结论
    private String sjxmjl;
    //省级备注
    private String sjbz;
    //项目分发时间
    private Date xmffsj;

    public Date getXmffsj() {
        return xmffsj;
    }

    public void setXmffsj(Date xmffsj) {
        this.xmffsj = xmffsj;
    }

    public String getXjxmjl() {
        return xjxmjl;
    }

    public void setXjxmjl(String xjxmjl) {
        this.xjxmjl = xjxmjl;
    }

    public String getSjxmjl() {
        return sjxmjl;
    }

    public void setSjxmjl(String sjxmjl) {
        this.sjxmjl = sjxmjl;
    }

    public String getSjbz() {
        return sjbz;
    }

    public void setSjbz(String sjbz) {
        this.sjbz = sjbz;
    }

    public String getSfqdghxy() {
        return sfqdghxy;
    }

    public void setSfqdghxy(String sfqdghxy) {
        this.sfqdghxy = sfqdghxy;
    }

    public String getXmid() {
        return xmid;
    }

    public void setXmid(String xmid) {
        this.xmid = xmid;
    }

    public String getXmbh() {
        return xmbh;
    }

    public void setXmbh(String xmbh) {
        this.xmbh = xmbh;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public String getXzqdm() {
        return xzqdm;
    }

    public void setXzqdm(String xzqdm) {
        this.xzqdm = xzqdm;
    }

    public String getXzqmc() {
        return xzqmc;
    }

    public void setXzqmc(String xzqmc) {
        this.xzqmc = xzqmc;
    }

    public String getYsbh() {
        return ysbh;
    }

    public void setYsbh(String ysbh) {
        this.ysbh = ysbh;
    }

    public Integer getDkgs() {
        return dkgs;
    }

    public void setDkgs(Integer dkgs) {
        this.dkgs = dkgs;
    }

    public Integer getYjzdkgs() {
        return yjzdkgs;
    }

    public void setYjzdkgs(Integer yjzdkgs) {
        this.yjzdkgs = yjzdkgs;
    }

    public String getYswh() {
        return yswh;
    }

    public void setYswh(String yswh) {
        this.yswh = yswh;
    }

    public Date getYssj() {
        return yssj;
    }

    public void setYssj(Date yssj) {
        this.yssj = yssj;
    }

    public Float getXmjsgm() {
        return xmjsgm;
    }

    public void setXmjsgm(Float xmjsgm) {
        this.xmjsgm = xmjsgm;
    }

    public Float getXzgdmj() {
        return xzgdmj;
    }

    public void setXzgdmj(Float xzgdmj) {
        this.xzgdmj = xzgdmj;
    }

    public Float getXmzzj() {
        return xmzzj;
    }

    public void setXmzzj(Float xmzzj) {
        this.xmzzj = xmzzj;
    }

    public String getXmqfw() {
        return xmqfw;
    }

    public void setXmqfw(String xmqfw) {
        this.xmqfw = xmqfw;
    }

    public String getXjhcr() {
        return xjhcr;
    }

    public void setXjhcr(String xjhcr) {
        this.xjhcr = xjhcr;
    }

    public String getXjhczt() {
        return xjhczt;
    }

    public void setXjhczt(String xjhczt) {
        this.xjhczt = xjhczt;
    }

    public Date getXjhcsj() {
        return xjhcsj;
    }

    public void setXjhcsj(Date xjhcsj) {
        this.xjhcsj = xjhcsj;
    }

    public String getXjhcyj() {
        return xjhcyj;
    }

    public void setXjhcyj(String xjhcyj) {
        this.xjhcyj = xjhcyj;
    }

    public String getSjhczt() {
        return sjhczt;
    }

    public void setSjhczt(String sjhczt) {
        this.sjhczt = sjhczt;
    }

    public String getSjhcr() {
        return sjhcr;
    }

    public void setSjhcr(String sjhcr) {
        this.sjhcr = sjhcr;
    }

    public Date getSjhcsj() {
        return sjhcsj;
    }

    public void setSjhcsj(Date sjhcsj) {
        this.sjhcsj = sjhcsj;
    }

    public String getSjhcyj() {
        return sjhcyj;
    }

    public void setSjhcyj(String sjhcyj) {
        this.sjhcyj = sjhcyj;
    }

    public String getXmjzzt() {
        return xmjzzt;
    }

    public void setXmjzzt(String xmjzzt) {
        this.xmjzzt = xmjzzt;
    }

    public String getSfcxjz() {
        return sfcxjz;
    }

    public void setSfcxjz(String sfcxjz) {
        this.sfcxjz = sfcxjz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
